@@ -88,7 +88,7 @@ class QueryEncoder:
 class TctColBertQueryEncoder(QueryEncoder):
 
     def __init__(self, encoder_dir: str = None, tokenizer_name: str = None,
-                 encoded_query_dir: str = None, device: str = 'cpu'):
+                 encoded_query_dir: str = None, device: str = 'cpu', **kwargs):
         super().__init__(encoded_query_dir)
         if encoder_dir:
             self.device = device
@@ -120,7 +120,7 @@ class TctColBertQueryEncoder(QueryEncoder):
 class DprQueryEncoder(QueryEncoder):
 
     def __init__(self, encoder_dir: str = None, tokenizer_name: str = None,
-                 encoded_query_dir: str = None, device: str = 'cpu'):
+                 encoded_query_dir: str = None, device: str = 'cpu', **kwargs):
         super().__init__(encoded_query_dir)
         if encoder_dir:
             self.device = device
@@ -144,7 +144,7 @@ class DprQueryEncoder(QueryEncoder):
 class BprQueryEncoder(QueryEncoder):
 
     def __init__(self, encoder_dir: str = None, tokenizer_name: str = None,
-                 encoded_query_dir: str = None, device: str = 'cpu'):
+                 encoded_query_dir: str = None, device: str = 'cpu', **kwargs):
         self.has_model = False
         self.has_encoded_query = False
         if encoded_query_dir:
@@ -187,7 +187,7 @@ class BprQueryEncoder(QueryEncoder):
 class DkrrDprQueryEncoder(QueryEncoder):
 
     def __init__(self, encoder_dir: str = None, encoded_query_dir: str = None, device: str = 'cpu',
-                 prefix: str = "question:"):
+                 prefix: str = "question:", **kwargs):
         super().__init__(encoded_query_dir)
         self.device = device
         self.model = BertModel.from_pretrained(encoder_dir)
@@ -219,7 +219,7 @@ class DkrrDprQueryEncoder(QueryEncoder):
 class AnceQueryEncoder(QueryEncoder):
 
     def __init__(self, encoder_dir: str = None, tokenizer_name: str = None,
-                 encoded_query_dir: str = None, device: str = 'cpu'):
+                 encoded_query_dir: str = None, device: str = 'cpu', **kwargs):
         super().__init__(encoded_query_dir)
         if encoder_dir:
             self.device = device
@@ -281,13 +281,16 @@ class AutoQueryEncoder(QueryEncoder):
 
     def __init__(self, encoder_dir: str = None, tokenizer_name: str = None,
                  encoded_query_dir: str = None, device: str = 'cpu',
-                 pooling: str = 'cls', l2_norm: bool = False):
+                 pooling: str = 'cls', l2_norm: bool = False, **kwargs):
         super().__init__(encoded_query_dir)
         if encoder_dir:
             self.device = device
             self.model = AutoModel.from_pretrained(encoder_dir)
             self.model.to(self.device)
-            self.tokenizer = AutoTokenizer.from_pretrained(tokenizer_name or encoder_dir)
+            try:
+                self.tokenizer = AutoTokenizer.from_pretrained(tokenizer_name or encoder_dir)
+            except:
+                self.tokenizer = AutoTokenizer.from_pretrained(tokenizer_name or encoder_dir, use_fast=False)
             self.has_model = True
             self.pooling = pooling
             self.l2_norm = l2_norm
@@ -306,11 +309,13 @@ class AutoQueryEncoder(QueryEncoder):
         if self.has_model:
             inputs = self.tokenizer(
                 query,
-                padding='longest',
-                truncation=True,
                 add_special_tokens=True,
-                return_tensors='pt'
+                return_tensors='pt',
+                truncation='only_first',
+                padding='longest',
+                return_token_type_ids=False,
             )
+
             inputs.to(self.device)
             outputs = self.model(**inputs)
             if self.pooling == "mean":
