@@ -719,6 +719,7 @@ class TestLoadTopics(unittest.TestCase):
         self.assertIsNotNone(topics)
         self.assertEqual(len(topics), 1190)
         self.assertTrue(isinstance(next(iter(topics.keys())), int))
+        
 
     def test_beir(self):
         topics = search.get_topics('beir-v1.0.0-trec-covid-test')
@@ -836,6 +837,117 @@ class TestLoadTopics(unittest.TestCase):
         topics = search.get_topics('beir-v1.0.0-scifact-test')
         self.assertIsNotNone(topics)
         self.assertEqual(len(topics), 300)
+    
+    def test_hc4_1_0_fa(self):
+        topics = search.get_topics('hc4-v1.0-fa-test-title')
+        self.assertIsNotNone(topics)
+        self.assertEqual(len(topics), 50)
+        self.assertTrue(isinstance(next(iter(topics.keys())), int))
+
+        topics = search.get_topics('hc4-v1.0-fa-test-description')
+        self.assertIsNotNone(topics)
+        self.assertEqual(len(topics), 50)
+        self.assertTrue(isinstance(next(iter(topics.keys())), int))
+        
+        """
+        Test case commented out pending the upgrade to Lucene 9.0
+        """
+        # topics = search.get_topics('hc4-v1.0-fa-test-description-title')
+        # self.assertIsNotNone(topics)
+        # self.assertEqual(len(topics), 50)
+        # self.assertTrue(isinstance(next(iter(topics.keys())), int))
+
+        topics = search.get_topics('hc4-v1.0-fa-dev-title')
+        self.assertIsNotNone(topics)
+        self.assertEqual(len(topics), 10)
+        self.assertTrue(isinstance(next(iter(topics.keys())), int))
+
+        topics = search.get_topics('hc4-v1.0-fa-dev-description')
+        self.assertIsNotNone(topics)
+        self.assertEqual(len(topics), 10)
+        self.assertTrue(isinstance(next(iter(topics.keys())), int))
+
+        """
+        Test case commented out pending the upgrade to Lucene 9.0
+        """
+        # topics = search.get_topics('hc4-v1.0-fa-dev-description-title')
+        # self.assertIsNotNone(topics)
+        # self.assertEqual(len(topics), 10)
+        # self.assertTrue(isinstance(next(iter(topics.keys())), int))
+    
+    def test_hc4_1_0_zh(self):
+        topics = search.get_topics('hc4-v1.0-zh-test-title')
+        self.assertIsNotNone(topics)
+        self.assertEqual(len(topics), 50)
+        self.assertTrue(isinstance(next(iter(topics.keys())), int))
+
+        topics = search.get_topics('hc4-v1.0-zh-test-description')
+        self.assertIsNotNone(topics)
+        self.assertEqual(len(topics), 50)
+        self.assertTrue(isinstance(next(iter(topics.keys())), int))
+
+        """
+        Test case commented out pending the upgrade to Lucene 9.0
+        """
+        # topics = search.get_topics('hc4-v1.0-zh-test-description-title')
+        # self.assertIsNotNone(topics)
+        # self.assertEqual(len(topics), 50)
+        # self.assertTrue(isinstance(next(iter(topics.keys())), int))
+
+        topics = search.get_topics('hc4-v1.0-zh-dev-title')
+        self.assertIsNotNone(topics)
+        self.assertEqual(len(topics), 10)
+        self.assertTrue(isinstance(next(iter(topics.keys())), int))
+
+        topics = search.get_topics('hc4-v1.0-zh-dev-description')
+        self.assertIsNotNone(topics)
+        self.assertEqual(len(topics), 10)
+        self.assertTrue(isinstance(next(iter(topics.keys())), int))
+
+        """
+        Test case commented out pending the upgrade to Lucene 9.0
+        """
+        # topics = search.get_topics('hc4-v1.0-zh-dev-description-title')
+        # self.assertIsNotNone(topics)
+        # self.assertEqual(len(topics), 10)
+        # self.assertTrue(isinstance(next(iter(topics.keys())), int))
+    
+    def test_hc4_1_0_ru(self):
+        topics = search.get_topics('hc4-v1.0-ru-test-title')
+        self.assertIsNotNone(topics)
+        self.assertEqual(len(topics), 50)
+        self.assertTrue(isinstance(next(iter(topics.keys())), int))
+
+        topics = search.get_topics('hc4-v1.0-ru-test-description')
+        self.assertIsNotNone(topics)
+        self.assertEqual(len(topics), 50)
+        self.assertTrue(isinstance(next(iter(topics.keys())), int))
+
+        """
+        Test case commented out pending the upgrade to Lucene 9.0
+        """
+        # topics = search.get_topics('hc4-v1.0-ru-test-description-title')
+        # self.assertIsNotNone(topics)
+        # self.assertEqual(len(topics), 50)
+        # self.assertTrue(isinstance(next(iter(topics.keys())), int))
+
+        topics = search.get_topics('hc4-v1.0-ru-dev-title')
+        self.assertIsNotNone(topics)
+        self.assertEqual(len(topics), 4)
+        self.assertTrue(isinstance(next(iter(topics.keys())), int))
+
+        topics = search.get_topics('hc4-v1.0-ru-dev-description')
+        self.assertIsNotNone(topics)
+        self.assertEqual(len(topics), 4)
+        self.assertTrue(isinstance(next(iter(topics.keys())), int))
+
+        """
+        Test case commented out pending the upgrade to Lucene 9.0
+        """
+        # topics = search.get_topics('hc4-v1.0-ru-dev-description-title')
+        # self.assertIsNotNone(topics)
+        # self.assertEqual(len(topics), 4)
+        # self.assertTrue(isinstance(next(iter(topics.keys())), int))
 
     # General test cases
     def test_tsv_int_topicreader(self):
